module SwitchExampleSpec exposing (suite)

import Accessibility.Aria as Aria
import Accessibility.Role as Role
import Examples.Switch exposing (example)
import Nri.Test.MouseHelpers.V1 as MouseHelpers
import ProgramTest exposing (..)
import Routes exposing (Route)
import Test exposing (..)
import Test.Html.Event as Event
import Test.Html.Query as Query
import Test.Html.Selector as Selector exposing (..)
import TestApp exposing (app)


route : Route
route =
    Routes.exampleRoute example


suite : Test
suite =
    describe "Switch"
        [ test "it works" <|
            \() ->
                app route
                    |> ensureViewHas [ text "Nri.Ui.Switch" ]
                    -- switch starts with aria-checked=true
                    |> ensureViewHas [ attribute (Aria.checked (Just True)) ]
                    -- user can click the first switch
                    |> switchIt "Show pandas in results"
                    -- the switch now has aria-checked=false
                    |> ensureViewHas [ attribute (Aria.checked (Just False)) ]
                    |> done
        ]


switchIt : String -> ProgramTest a b c -> ProgramTest a b c
switchIt name =
    MouseHelpers.click
        mhConfig
        [ attribute Role.switch
        , containing [ text name ]
        , id "view-switch-example"
        ]


mhConfig : MouseHelpers.Config (ProgramTest model msg effect) Selector.Selector (Query.Single msg)
mhConfig =
    { programTest_simulateDomEvent = ProgramTest.simulateDomEvent
    , query_find = Query.find
    , event_click = Event.click
    , event_mouseDown = Event.mouseDown
    , event_mouseUp = Event.mouseUp
    , event_mouseOver = Event.mouseOver
    , event_custom = Event.custom
    }
